@@ -2,7 +2,7 @@ context("wdpa_fetch")
 
 test_that("country name", {
   skip_on_cran()
-  skip_if_not(pingr::is_online())
+  skip_if_not(curl::has_internet())
   x <- suppressWarnings(wdpa_fetch("Liechtenstein", force = TRUE, wait = TRUE))
   expect_is(x, "sf")
   expect_true(all(x$ISO3 == "LIE"))
@@ -10,7 +10,7 @@ test_that("country name", {
 
 test_that("ISO3", {
   skip_on_cran()
-  skip_if_not(pingr::is_online())
+  skip_if_not(curl::has_internet())
   x <- suppressWarnings(wdpa_fetch("LIE", force = TRUE, wait = TRUE))
   expect_is(x, "sf")
   expect_true(all(x$ISO3 == "LIE"))
